@@ -1,4 +1,4 @@
-# $Id: Polyglot.pm,v 1.3 2003/01/21 03:52:00 comdog Exp $
+# $Id: Polyglot.pm,v 1.4 2004/09/16 02:26:48 comdog Exp $
 package Polyglot;
 use strict;
 use vars qw($VERSION);
@@ -56,11 +56,11 @@ use autouse 'Data::Dumper' => 'Dumper';
 use Carp qw(carp);
 use Text::ParseWords qw( quotewords );
 
-$VERSION = '0.07';
+$VERSION = '0.10';
 
 my $Debug = $ENV{DEBUG} || 0;
 
-=head2 METHODS
+=head2 Methods
 
 =over 4
 
@@ -135,7 +135,7 @@ sub run
 
 		print "$prompt" if $ARGV eq '-';
 		}
-		
+
 	print "\n";
 	}
 
@@ -341,18 +341,18 @@ access a Singleton object stored as class data.
 This source is part of a SourceForge project which always has the
 latest sources in CVS, as well as all of the previous releases.
 
-        https://sourceforge.net/projects/brian-d-foy/
+        http://sourceforge.net/projects/brian-d-foy/
 
 If, for some reason, I disappear from the world, one of the other
 members of the project can shepherd this module appropriately.
 
 =head1 AUTHOR
 
-brian d foy, E<lt>bdfoy@cpan.orgE<gt>.
+brian d foy, C<< <bdfoy@cpan.org> >>.
 
 =head1 COPYRIGHT and LICENSE
 
-Copyright 2003, brian d foy, All rights reserved
+Copyright 2004, brian d foy, All rights reserved
 
 This software is available under the same terms as perl.
 
